/* Upgrade Story Tracker database from v3 to v4 */

begin exclusive transaction;

/* Create tables if they don't already exist */
create table if not exists story (pk INTEGER PRIMARY KEY, title CHAR(200), wordcount INTEGER, genre CHAR(200), notes CHAR(10000), trunked BOOLEAN);
create table if not exists market (pk INTEGER PRIMARY KEY, title CHAR(200), genre CHAR(200), editor CHAR(200), address1 CHAR(200), address2 CHAR(200), address3 CHAR(200), url CHAR(200), email CHAR(200), phone CHAR(200), fax CHAR(200), open BOOLEAN, notes CHAR(10000), responsetime INTEGER, responsetimeunits INTEGER, wordlimit INTEGER, payrate REAL, payrateunits INTEGER, deadline REAL);
create table if not exists submission (pk INTEGER PRIMARY KEY, storykey INTEGER, marketkey INTEGER, sentdate REAL, response INTEGER, responsedate REAL, state INTEGER, income REAL, validduedate BOOLEAN, responseduedate REAL, notes CHAR(10000));
create table if not exists genre (pk INTEGER PRIMARY KEY, name CHAR(200));

/* Copy existing data into new tables */
create table old_story as select * from story;
create table old_market as select * from market;
create table old_submission as select * from submission;
create table old_genre as select * from genre;

/* Drop old tables */
drop table story;
drop table market;
drop table submission;
drop table genre;

/* Create new story table with larger fields */
CREATE TABLE story (pk INTEGER PRIMARY KEY, title CHAR(200), wordcount INTEGER, genre CHAR(200), notes CHAR(10000), trunked BOOLEAN);

/* Create new market table with new and larger fields */
CREATE TABLE market (pk INTEGER PRIMARY KEY, title CHAR(200), genre CHAR(200), editor CHAR(200), address1 CHAR(200), address2 CHAR(200), address3 CHAR(200), url CHAR(200), email CHAR(200), phone CHAR(200), fax CHAR(200), open BOOLEAN, notes CHAR(10000), responsetime INTEGER, responsetimeunits INTEGER, wordlimit INTEGER, payrate REAL, payrateunits INTEGER, deadline REAL);

/* Create new submission table with larger fields */
CREATE TABLE submission (pk INTEGER PRIMARY KEY, storykey INTEGER, marketkey INTEGER, sentdate REAL, response INTEGER, responsedate REAL, state INTEGER, income REAL, validduedate BOOLEAN, responseduedate REAL, notes CHAR(10000));

/* Create new genre table with larger name field */
CREATE TABLE genre (pk INTEGER PRIMARY KEY, name CHAR(200));

/* Copy old data back into tables */
insert into story (pk, title, wordcount, genre, notes, trunked) select pk, title, wordcount, genre, notes, trunked from old_story;

insert into market (pk, title, genre, editor, address1, address2, address3, url, email, phone, fax, open, notes, responsetime, responsetimeunits, wordlimit, payrate, payrateunits) select pk, title, genre, editor, address1, address2, address3, url, email, phone, fax, open, notes, responsetime, responsetimeunits, wordlimit, payrate, payrateunits from old_market;

insert into submission (pk, storykey, marketkey, sentdate, response, responsedate, state, income, validduedate, responseduedate, notes) select pk, storykey, marketkey, sentdate, response, responsedate, state, income, validduedate, responseduedate, notes from old_submission;

insert into genre (pk, name) select pk, name from old_genre;

/* Remove temporary tables */
drop table old_story;
drop table old_market;
drop table old_submission;
drop table old_genre;

/* Update database version number */
update version set version_num = 4;

commit;

/* Compact database */
vacuum;
